@@ -227,10 +227,12 @@ bool IncidenceBase::accept(Visitor &v, const IncidenceBase::Ptr &incidence)
 
 void IncidenceBase::setUid(const QString &uid)
 {
-    update();
-    d->mUid = uid;
-    d->mDirtyFields.insert(FieldUid);
-    updated();
+    if (d->mUid != uid) {
+        update();
+        d->mUid = uid;
+        d->mDirtyFields.insert(FieldUid);
+        updated();
+    }
 }
 
 QString IncidenceBase::uid() const
@@ -313,11 +315,13 @@ void IncidenceBase::setDtStart(const KDateTime &dtStart)
         qCWarning(KCALCORE_LOG) << "Invalid dtStart";
     }
 
-    update();
-    d->mDtStart = dtStart;
-    d->mAllDay = dtStart.isDateOnly();
-    d->mDirtyFields.insert(FieldDtStart);
-    updated();
+    if (d->mDtStart != dtStart || d->mAllDay != dtStart.isDateOnly()) {
+        update();
+        d->mDtStart = dtStart;
+        d->mAllDay = dtStart.isDateOnly();
+        d->mDirtyFields.insert(FieldDtStart);
+        updated();
+    }
 }
 
 KDateTime IncidenceBase::dtStart() const
